/*
 * Copyright 2002 Niels Provos <provos@citi.umich.edu>
 * All rights reserved.
 *  
 */
/*
 * Initial main.c file generated by Glade. Edit as required.
 * Glade will not overwrite this file.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include <sys/types.h>
#include <sys/queue.h>

#include "interface.h"
#include "support.h"

#include "dag.h"

GtkWidget *mainwindow;
GtkWidget *loadtopology;
GtkWidget *warningdialog;
GtkWidget *aboutwindow;
GtkWidget *drawingarea;
GtkStyle *yellow;
GtkStyle *blue;
GtkStyle *red;
GtkStyle *green;

GtkStyle *
make_color(GtkStyle *default_style, int hexred, int hexgreen, int hexblue)
{
	GdkColormap *cmap;
	GdkColor color;
	GtkStyle *style;

	cmap = gdk_colormap_get_system();

	color.red = hexred * 256;
	color.green = hexgreen * 256;
	color.blue = hexblue * 256;
	if (!gdk_color_alloc(cmap, &color)) {
		g_error("Could not allocate color");
	}

	style = gtk_style_copy(default_style);
	if (style->fg_gc[GTK_STATE_NORMAL] == NULL)
		style->fg_gc[GTK_STATE_NORMAL] = gdk_gc_new(drawingarea->window);
	gdk_gc_set_foreground(style->fg_gc[GTK_STATE_NORMAL], &color);

	return (style);
}

int
main (int argc, char *argv[])
{
	extern int want_nodes;
	extern int num_iterations;
	GtkWidget *entry;
	GtkObject *adj;
	GtkStyle *defaultstyle;

  dag_init();

  gtk_set_locale ();
  gtk_init (&argc, &argv);

  add_pixmap_directory (PACKAGE_DATA_DIR "/pixmaps");
  add_pixmap_directory (PACKAGE_SOURCE_DIR "/pixmaps");

  /*
   * The following code was added by Glade to create one of each component
   * (except popup menus), just so that you see something after building
   * the project. Delete any components that you don't want shown initially.
   */
  mainwindow = create_mainwindow();
  loadtopology = create_loadtopology();
  warningdialog = create_warningdialog();
  aboutwindow = create_aboutwindow();

  gtk_widget_show (mainwindow);

  drawingarea = lookup_widget(GTK_WIDGET(mainwindow), "drawingarea1");
  gtk_drawing_area_size(GTK_DRAWING_AREA(drawingarea), 2048, 2048);

  entry = lookup_widget(GTK_WIDGET(mainwindow), "entry1");

  adj = gtk_adjustment_new (1, 0, 10000, 1, 10, 10);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "50");
  want_nodes = 50;

  entry = lookup_widget(GTK_WIDGET(mainwindow), "nriterations");
  adj = gtk_adjustment_new (10, 0, 10000, 1, 10, 10);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "10");
  num_iterations = 10;

  entry = lookup_widget(GTK_WIDGET(mainwindow), "attractcenter");
  adj = gtk_adjustment_new (0.02, -2, 2, 0.01, 0.1, 1000);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "0.06");

  entry = lookup_widget(GTK_WIDGET(mainwindow), "repulsecenter");
  adj = gtk_adjustment_new (0.00001, -2, 2, 0.001, 0.01, 1000);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "0.00001");

  entry = lookup_widget(GTK_WIDGET(mainwindow), "attractdist");
  adj = gtk_adjustment_new (800, 1, 5000, 10, 100, 5000);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "800");

  entry = lookup_widget(GTK_WIDGET(mainwindow), "repulsedist");
  adj = gtk_adjustment_new (0.001, 0.00001, 2, 0.001, 0.01, 10000);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "0.001");

  entry = lookup_widget(GTK_WIDGET(mainwindow), "repulseconst");
  adj = gtk_adjustment_new (150.0, 0.1, 1000, 1, 10, 10000);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "150.0");

  entry = lookup_widget(GTK_WIDGET(mainwindow), "attractconst");
  adj = gtk_adjustment_new (0.01, 0.0001, 10, 0.0001, 0.001, 10000);
  gtk_spin_button_set_adjustment (GTK_SPIN_BUTTON(entry), GTK_ADJUSTMENT(adj));
  gtk_entry_set_text(GTK_ENTRY(entry), "0.01");

  defaultstyle = gtk_widget_get_style(drawingarea);

  red = make_color(defaultstyle, 255, 0, 0);
  green = make_color(defaultstyle, 0, 255, 0);
  yellow = make_color(defaultstyle, 255, 255, 0);
  blue = make_color(defaultstyle, 0, 0, 255);

  gtk_main ();
  return 0;
}

